@@ -10,3 +10,13 @@ expect_true(all(bools))
 results <- run_test_file(system.file("tinytest/programming.R",package="tinytest"), verbose=FALSE)
 expect_equal(11, length(results))
 
+expect_true(all_pass(results))
+expect_false(any_fail(results))
+expect_false(all_fail(results))
+expect_true(any_pass(results))
+
+expect_error(all_pass("hihi"))
+expect_error(any_pass("hihi"))
+expect_error(all_fail("hihi"))
+expect_error(any_fail("hihi"))
+
