@@ -44,4 +44,17 @@ expect_false(ignore(expect_error)(stop("foo"),pattern="bar"))
 expect_true(ignore(expect_warning)(warning("fu!")))
 expect_false(ignore(expect_warning)(warning("fu!"), pattern="bar"))
 
+expect_true(ignore(expect_silent)(1 + 1))
+expect_false(ignore(expect_silent)(1 + "a"))
+expect_false(ignore(expect_silent)(1:3 + 1:2))
+
+expect_false(ignore(expect_message)(message("hihi"),"lol"))
+expect_false(ignore(expect_message)(stop("hihi"),"lol"))
+expect_false(ignore(expect_message)(warning("hihi"),"lol"))
+expect_message(message("hihi, I lol"),"lol")
+
+
+
+
+
 
